@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.15.2.2 2001/04/20 14:33:07 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.15.2.3 2001/05/05 14:13:57 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -980,9 +980,10 @@ static int ip_vs_tunnel_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	iph->saddr		=	rt->rt_src;
 	iph->ttl		=	old_iph->ttl;
 	iph->tot_len		=	htons(skb->len);
-	ip_select_ident(iph, &rt->u.dst);
+	ip_select_ident(iph, &rt->u.dst, NULL);
 	ip_send_check(iph);
 
+	skb->ip_summed = CHECKSUM_NONE;
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
